Crate dw_openmw_cfg

Crate dw_openmw_cfg 

Structs

Ini
Ini struct

Enums

Error
VFSFile

Functions

config_path
Returns the path of openmw.cfg
find_file
Searches the openmw vfs for the given file Returns the absolute path of the file within the VFS
find_file_or_archive
Searches the openmw vfs for the given file Returns the absolute path of the file within the VFS If the file is within an archive, returns the path of the archive
get_archives
Returns the absolute paths of the fallback-archives listed in openmw.cfg
get_config
Returns an Ini object for openmw.cfg
get_data_dirs
Returns the data directories listed in openmw.cfg
get_data_local_dir
Returns the openmw userdata directory This is where game files such as saves and navmesh.db are stored The OPENMW_OVERRIDE_DIR environment variable may override this location as well as data-local entries in openmw.cfg, which take priority over the environment variable when used.
get_encoding
Fetches encoding from openmw.cfg
get_plugins
Returns the absolute paths of the plugins listed in openmw.cfg
get_userdata_dir
Returns the openmw userdata directory This is where game files such as saves and navmesh.db are stored The OPENMW_USERDATA_DIR environment variable may override this location as well as user-data entries in openmw.cfg, which take priority over the environment variable when used.
read_file
Searches the openmw vfs for the given file and returns its contents