Searches the openmw vfs for the given file
Returns the absolute path of the file within the VFS
If the file is within an archive, returns the path of the archive
Returns the openmw userdata directory
This is where game files such as saves and navmesh.db are stored
The OPENMW_OVERRIDE_DIR environment variable may override this location
as well as data-local entries in openmw.cfg, which take priority over the environment variable when used.
Returns the openmw userdata directory
This is where game files such as saves and navmesh.db are stored
The OPENMW_USERDATA_DIR environment variable may override this location
as well as user-data entries in openmw.cfg, which take priority over the environment variable when used.